@@ -8,12 +8,10 @@ from typedpy.stubs.type_helpers import (
 )
 
 
-def get_base_parser() -> argparse.ArgumentParser:
+# pylint: disable=R0801
+def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("src_root_dir", help="source root directory")
-    parser.add_argument(
-        "src_script_path", help="absolute path of python script to process"
-    )
     parser.add_argument(
         "-s",
         "--stubs-dir",
@@ -27,11 +25,9 @@ def get_base_parser() -> argparse.ArgumentParser:
         type=str,
         help="exclude patterns in the form path1:path2:path3",
     )
-    return parser
-
-
-def main():
-    parser = get_base_parser()
+    parser.add_argument(
+        "src_script_path", help="absolute path of python script to process"
+    )
     parser.add_argument(
         "--ast",
         action=argparse.BooleanOptionalAction,
