@@ -4,6 +4,7 @@ import json
 import uuid
 from functools import lru_cache
 from typing import Dict
+from decimal import Decimal
 
 from typedpy.commons import (
     Constant,
@@ -13,7 +14,7 @@ from typedpy.commons import (
     wrap_val,
 )
 from typedpy.serialization.versioned_mapping import (
-    VERSION_MAPPING,
+    VERSIONS_MAPPING,
     Versioned,
     convert_dict,
 )
@@ -424,6 +425,7 @@ def construct_fields_map(
     mapper,
     input_dict,
     cls,
+    use_strict_mapping=False,
     camel_case_convert=False,
     ignore_none=False,
     enable_undefined=False,
@@ -439,7 +441,11 @@ def construct_fields_map(
         processed_input = None
         if key in mapper:
             processed_input = get_processed_input(
-                key, mapper, input_dict, enable_undefined=enable_undefined
+                key,
+                mapper,
+                input_dict,
+                enable_undefined=enable_undefined,
+                use_strict_mapping=use_strict_mapping,
             )
             if processed_input is not None or getattr(cls, ENABLE_UNDEFINED, False):
                 process = True
@@ -529,6 +535,7 @@ def deserialize_structure_internal(
     the_dict,
     name=None,
     *,
+    use_strict_mapping=False,
     mapper=None,
     keep_undefined=False,
     camel_case_convert=False,
@@ -561,8 +568,8 @@ def deserialize_structure_internal(
     if issubclass(cls, Versioned):
         if not isinstance(the_dict, dict) or "version" not in the_dict:
             raise TypeError("Expected a dictionary with a 'version' value")
-        if getattr(cls, VERSION_MAPPING):
-            versions_mapping = getattr(cls, VERSION_MAPPING)
+        if getattr(cls, VERSIONS_MAPPING):
+            versions_mapping = getattr(cls, VERSIONS_MAPPING)
             input_dict = convert_dict(the_dict, versions_mapping)
 
     if (
@@ -637,6 +644,7 @@ def deserialize_structure_internal(
             mapper,
             input_dict,
             cls=cls,
+            use_strict_mapping=use_strict_mapping,
             camel_case_convert=camel_case_convert,
             ignore_none=ignore_none,
             enable_undefined=getattr(cls, ENABLE_UNDEFINED, False),
@@ -650,6 +658,7 @@ def deserialize_structure(
     cls,
     the_dict,
     *,
+    use_strict_mapping=False,
     mapper=None,
     keep_undefined=True,
     camel_case_convert=False,
@@ -664,6 +673,9 @@ def deserialize_structure(
             The target class
         the_dict(dict):
             the source dictionary
+        use_strict_mapping(bool): Optional
+            If True, in case a mapper maps field "x" to a key "y" in the input, will not use key "x" in the input
+            event if value for "y" does not exist. Default is False.
         mapper(dict): optional
             the key is the target attribute name. The value can either be a path of the value in the source dict
             using dot notation, for example: "aaa.bbb", or a :class:`FunctionCall`. In the latter case,
@@ -680,6 +692,7 @@ def deserialize_structure(
     return deserialize_structure_internal(
         cls,
         the_dict,
+        use_strict_mapping=use_strict_mapping,
         mapper=mapper,
         keep_undefined=keep_undefined,
         camel_case_convert=camel_case_convert,
@@ -690,7 +703,7 @@ def deserialize_structure(
 SENTITNEL = uuid.uuid4()
 
 
-def get_processed_input(key, mapper, the_dict, *, enable_undefined):
+def get_processed_input(key, mapper, the_dict, *, enable_undefined, use_strict_mapping):
     def _get_arg_list(key_mapper):
         vals = [deep_get(the_dict, k, default=SENTITNEL) for k in key_mapper.args]
         return [v for v in vals if v != SENTITNEL]
@@ -701,7 +714,9 @@ def get_processed_input(key, mapper, the_dict, *, enable_undefined):
         processed_input = key_mapper.func(*args) if args else None
     elif isinstance(key_mapper, (str,)):
         val = deep_get(the_dict, key_mapper, enable_undefined=enable_undefined)
-        processed_input = val if val is not None else the_dict.get(key)
+        processed_input = (
+            val if (val is not None or use_strict_mapping) else the_dict.get(key)
+        )
     elif isinstance(key_mapper, Constant):
         processed_input = key_mapper()
     else:
@@ -739,7 +754,7 @@ def serialize_val(
             field_definition.get_fields(), name, val, mapper, camel_case_convert
         )
     if isinstance(field_definition, (Number, Boolean, String)) or val is None:
-        return val
+        return str(val) if isinstance(val, Decimal) else val
     if isinstance(field_definition, Anything) and (
         isinstance(val, (int, float, str, bool)) or val is None
     ):
@@ -807,8 +822,22 @@ def serialize_val(
     if isinstance(field_definition, Anything) and isinstance(val, Structure):
         return serialize(val, mapper=mapper, camel_case_convert=camel_case_convert)
     if isinstance(val, Structure) or isinstance(field_definition, Field):
+        resolved_mapper = (
+            aggregate_serialization_mappers(
+                val.__class__,
+                override_mapper=None,
+                camel_case_convert=camel_case_convert
+            )
+            if (
+                isinstance(field_definition, ClassReference)
+                and isinstance(val, field_definition.get_type)
+                and val.__class__ is not field_definition.get_type
+            )
+            else mapper
+        )
+
         return serialize_internal(
-            val, resolved_mapper=mapper, camel_case_convert=camel_case_convert
+            val, resolved_mapper=resolved_mapper, camel_case_convert=camel_case_convert
         )
     if isinstance(field_definition, Constant):
         return val.name if isinstance(val, enum.Enum) else val
