@@ -6,4 +6,4 @@ class TypedPyDefaults:
     uniqueness_features_enabled = False
     defensive_copy_on_get = True
     allow_none_for_optionals = False
-    block_unknown_consts = False
+    block_unknown_consts = True
